@@ -28,6 +28,7 @@ from functools import partial
 
 import attr
 import amun
+import matplotlib
 from thoth.python import Project
 
 from .beam import Beam
@@ -60,6 +61,10 @@ class DependencyMonkey:
         """Get beam instance used in the resolver."""
         return self.resolver.beam
 
+    def plot(self) -> matplotlib.figure.Figure:
+        """Plot info from Dependency Monkey run."""
+        return self.resolver.plot()
+
     def resolve(self, *, with_devel: bool = True, user_stack_scoring: bool = False) -> DependencyMonkeyReport:
         """Perform simulated annealing and run dependency monkey on products."""
         if user_stack_scoring:
