@@ -23,7 +23,6 @@ from typing import Optional
 from typing import Tuple
 import logging
 import math
-import operator
 import os
 
 from ..context import Context
@@ -32,11 +31,8 @@ from .td import TemporalDifference
 
 
 _LOGGER = logging.getLogger(__name__)
-# 0 means unlimited memory for policy learning.
-_MCTS_POLICY_SIZE = int(os.getenv("THOTH_MCTS_POLICY_SIZE", 0))
 # Percentage relative to `limit` for the heat-up part.
 _MCTS_HEAT_UP = int(os.getenv("THOTH_MCTS_HEAT_UP", 10))
-_MCTS_POLICY_SIZE_CHECK_ITERATION = 1024
 
 
 @attr.s(slots=True)
@@ -89,14 +85,6 @@ class MCTS(TemporalDifference):
         # We have reached a new final - get another next time.
         self._next_state = None
 
-        # We limit number of records stored from time to time. Using sorting in O(N*log(N)) from
-        # time to time appears to be much faster than keeping a min-heap queue with O(log(N)) overhead.
-        if _MCTS_POLICY_SIZE and self.context.iteration % _MCTS_POLICY_SIZE_CHECK_ITERATION == 0:
-            _LOGGER.warning("Shrinking learnt policy to %d entries", _MCTS_POLICY_SIZE)
-            self._policy = dict(
-                sorted(self._policy.items(), key=operator.itemgetter(1), reverse=True)[:_MCTS_POLICY_SIZE]
-            )
-
     def run(self) -> Tuple[State, Tuple[str, str, str]]:
         """Run MCTS with adaptive simulated annealing schedule."""
         # In a heat up part, we run TD-like learning on the first candidates, not to get stuck in one state
@@ -109,6 +97,15 @@ class MCTS(TemporalDifference):
         # in the beam is the one we keep as next expanded. If they do not match, the last added is not the next state
         # we wanted to expand - this is based on the MCTS logic.
         if self._next_state is not None and self._next_state is self.context.beam.get_last():
+            if self.keep_history:
+                self._temperature_history.append(
+                    (
+                        self._temperature,
+                        self._next_state is self.context.beam.max(),
+                        None,
+                        self.context.accepted_final_states_count,
+                    )
+                )
             return (
                 self._next_state,
                 self._next_state.get_random_unresolved_dependency(prefer_recent=True),
