@@ -18,8 +18,10 @@
 """Implementation of sieves used, specific for TensorFlow."""
 
 from .tf_cuda import TensorFlowCUDASieve
+from .tf_py39 import TensorFlowPython39Sieve
 
 
 __all__ = [
     "TensorFlowCUDASieve",
+    "TensorFlowPython39Sieve",
 ]
