@@ -57,7 +57,6 @@ class MKLThreadsWrap(Wrap):
         }
     ]
 
-    # As JSON patch does not have any direct way to test presence of an item in an array, we preprend the configuration.
     _ADVISED_MANIFEST_CHANGE_PREPEND = [
         {
             "apiVersion:": "apps.openshift.io/v1",
@@ -73,8 +72,15 @@ class MKLThreadsWrap(Wrap):
     @classmethod
     def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[Any, Any]]:
         """Include this wrap in adviser, once."""
-        if not builder_context.is_included(cls):
-            return {}
+        units_included = builder_context.get_included_wraps(cls)
+        if len(units_included) == 4:
+            return None
+        elif len(units_included) == 0:
+            return {"package_name": "torch"}
+        elif len(units_included) == 1:
+            return {"package_name": "pytorch"}
+        elif len(units_included) == 2:
+            return {"package_name": "intel-tensorflow"}
 
         return None
 
